#
# Query the DPM database and updates the 's_uid' and 'protocol' fields
#

package UpdateDpmDatabase;

use DBI;
use Common;
use strict;
use warnings; 

sub find_and_update_groups_field($) {
    my ($dbh_dpm) = @_;

    my ($select1, $select2, $select3);
    my $count = 0;

    my ($r_gid, $r_token, $poolname, $gid);
    $select1 = $dbh_dpm->prepare("
	SELECT r_gid, r_token 
        FROM dpm_pending_req");
    $select1->execute();

    while(($r_gid, $r_token) = $select1->fetchrow_array()) {
	Common::updateFieldInDpmWhereString($dbh_dpm, "dpm_pending_req", "groups", $r_gid, "r_token", $r_token);
	$count = $count+1;
    }

    $select2 = $dbh_dpm->prepare("
	SELECT r_gid, r_token
	FROM dpm_req");
    $select2->execute();

    while(($r_gid, $r_token) = $select2->fetchrow_array()) {
	Common::updateFieldInDpmWhereString($dbh_dpm, "dpm_req", "groups", $r_gid, "r_token", $r_token);
	$count = $count+1;
    }

    $select3 = $dbh_dpm->prepare("
	SELECT poolname, gid
	FROM dpm_pool");
    $select3->execute();

    while(($poolname, $gid) = $select3->fetchrow_array()) {
	Common::updateFieldInDpmWhereString($dbh_dpm, "dpm_pool", "groups", $gid, "poolname", $poolname);
	$count = $count+1 ;
    }

    $select1->finish;
    $select2->finish;
    $select3->finish;
    $dbh_dpm->commit;
    return $count;
}

sub modify_schema_before_updating_field_mysql($) {
	my ($dbh_dpm) = @_;

	$dbh_dpm->do ("ALTER TABLE dpm_req ADD groups VARCHAR(255)");
	$dbh_dpm->do ("ALTER TABLE dpm_pending_req ADD groups VARCHAR(255)");

	$dbh_dpm->do ("ALTER TABLE dpm_pool ADD groups VARCHAR(255) BINARY");

	$dbh_dpm->do ("DROP TABLE schema_version");
	$dbh_dpm->do ("CREATE TABLE schema_version_dpm (major INTEGER NOT NULL, minor INTEGER NOT NULL, patch INTEGER NOT NULL) TYPE=INNODB");
	$dbh_dpm->do ("INSERT INTO schema_version_dpm VALUES(3, 1, 0)");
	$dbh_dpm->commit;
}

sub modify_schema_before_updating_field_oracle($) {
        my ($dbh_dpm) = @_;

	$dbh_dpm->do ("ALTER TABLE dpm_req ADD groups VARCHAR2(255)");
	$dbh_dpm->do ("ALTER TABLE dpm_pending_req ADD groups VARCHAR2(255)");

	$dbh_dpm->do ("ALTER TABLE dpm_pool ADD groups VARCHAR2(255)");

	$dbh_dpm->do ("CREATE TABLE schema_version_dpm (major NUMBER(1), minor NUMBER(1), patch NUMBER(1))");
	$dbh_dpm->do ("INSERT INTO schema_version_dpm VALUES(3, 1, 0)");
	$dbh_dpm->commit;
}

sub modify_schema_after_updating_field_mysql($) {
	my ($dbh_dpm) = @_;

	$dbh_dpm->do ("ALTER TABLE dpm_pool DROP gid");
	$dbh_dpm->commit;
}

sub modify_schema_after_updating_field_oracle($) {
	my ($dbh_dpm) = @_;

	$dbh_dpm->do ("ALTER TABLE dpm_pool DROP COLUMN gid");
	$dbh_dpm->commit;
}



1;
